BUG/MINOR: htx: Exclude TCP proxies when the HTX mode is handled during startup

When tests are performed on the HTX mode during HAProxy startup, only HTTP
proxies are considered. It is important because, since the commit 1d2b586cd
("MAJOR: htx: Enable the HTX mode by default for all proxies"), the HTX is
enabled on all proxies by default. But for TCP proxies, it is "deactivated".

This patch must be backported to 1.9.
diff --git a/src/cfgparse.c b/src/cfgparse.c
index ffff9cc..9a03a02 100644
--- a/src/cfgparse.c
+++ b/src/cfgparse.c
@@ -3484,8 +3484,8 @@
 			int mode = (1 << (curproxy->mode == PR_MODE_HTTP));
 			const struct mux_proto_list *mux_ent;
 
-			/* Special case for HTX because it is still experimental */
-			if (curproxy->options2 & PR_O2_USE_HTX)
+			/* Special case for HTX because legacy HTTP still exists */
+			if (mode == PROTO_MODE_HTTP && (curproxy->options2 & PR_O2_USE_HTX))
 				mode = PROTO_MODE_HTX;
 
 			if (!bind_conf->mux_proto)
@@ -3513,8 +3513,8 @@
 			int mode = (1 << (curproxy->mode == PR_MODE_HTTP));
 			const struct mux_proto_list *mux_ent;
 
-			/* Special case for HTX because it is still experimental */
-			if (curproxy->options2 & PR_O2_USE_HTX)
+			/* Special case for HTX because legacy HTTP still exists */
+			if (mode == PROTO_MODE_HTTP && (curproxy->options2 & PR_O2_USE_HTX))
 				mode = PROTO_MODE_HTX;
 
 			if (!newsrv->mux_proto)